Generate search space — BAGO 0.0.1 documentation

# Generate search space

This function is implemented in the `gpModel` class to generate a search space.

genSearchSpace(self, parameters)

  Function to fit the data to Gaussian process regression model.

  Parameters:

    parameters – dict. A dictionary containing the parameters for finding the top signals.

It generates the following attributes in the `gpModel` object:

> - `gridX`: a numpy array containing the gradients for the search space.

> - `gradientPct`: a 1D numpy array containing the percentage of strong mobile phase used by each gradient in the search space.

> - `scaler`: a `sklearn.preprocessing.StandardScaler` object used to scale the data.

> - `scaledX`: a numpy array containing the scaled gradients for the search space.

To use this function:

    # You need a gpModel object (d).

    d.genSearchSpace(parameters)